util_simple_3d library
Classes
- FSp3dMaterial
- (en)This class statically stores the default set of Sp3dMaterial that is often used.
- IntVRange
- (en)A class that defines a range of values and makes it convenient to use.
- Sp3dConstantValues
- (en)This class is a collection of constants useful when using the simple_3d package.
- UtilBezier
- (en)A utility for calculating Bezier curves.
- UtilSearchValue
- (en)This is a utility for finding values close to a specified value.
- UtilSp3dCommonParts
- (en)A utility to generate common parts using sp3d. (ja)sp3dを使った一般的なパーツを生成するユーティリティです。
- UtilSp3dGeometry
- (en)It is a utility related to the three-dimensional structure using sp3d. (ja)sp3dを使った立体構造に関するユーティリティです。
- UtilSp3dList
- (en)A utility for easily manipulating lists when working with the simple_3d package.
- VRange
- (en)A class that defines a range of values and makes it convenient to use.